package com.bonus.material.warehouse.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.warehouse.domain.WhDirectApplyInfo;
import com.bonus.material.warehouse.service.IWhDirectApplyInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 工地直转信息Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "工地直转信息接口")
@RestController
@RequestMapping("/wh_direct_apply_info")
public class WhDirectApplyInfoController extends BaseController
{
    @Autowired
    private IWhDirectApplyInfoService whDirectApplyInfoService;

    /**
     * 查询工地直转信息列表
     */
    @ApiOperation(value = "查询工地直转信息列表")
    @RequiresPermissions("warehouse:info:list")
    @GetMapping("/list")
    public TableDataInfo list(WhDirectApplyInfo whDirectApplyInfo)
    {
        startPage();
        List<WhDirectApplyInfo> list = whDirectApplyInfoService.selectWhDirectApplyInfoList(whDirectApplyInfo);
        return getDataTable(list);
    }

    /**
     * 导出工地直转信息列表
     */
    @ApiOperation(value = "导出工地直转信息列表")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:info:export")
    @SysLog(title = "工地直转信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出工地直转信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, WhDirectApplyInfo whDirectApplyInfo)
    {
        List<WhDirectApplyInfo> list = whDirectApplyInfoService.selectWhDirectApplyInfoList(whDirectApplyInfo);
        ExcelUtil<WhDirectApplyInfo> util = new ExcelUtil<WhDirectApplyInfo>(WhDirectApplyInfo.class);
        util.exportExcel(response, list, "工地直转信息数据");
    }

    /**
     * 获取工地直转信息详细信息
     */
    @ApiOperation(value = "获取工地直转信息详细信息")
    @RequiresPermissions("warehouse:info:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(whDirectApplyInfoService.selectWhDirectApplyInfoById(id));
    }

    /**
     * 新增工地直转信息
     */
    @ApiOperation(value = "新增工地直转信息")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:info:add")
    @SysLog(title = "工地直转信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增工地直转信息")
    @PostMapping
    public AjaxResult add(@RequestBody WhDirectApplyInfo whDirectApplyInfo)
    {
        return toAjax(whDirectApplyInfoService.insertWhDirectApplyInfo(whDirectApplyInfo));
    }

    /**
     * 修改工地直转信息
     */
    @ApiOperation(value = "修改工地直转信息")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:info:edit")
    @SysLog(title = "工地直转信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改工地直转信息")
    @PutMapping
    public AjaxResult edit(@RequestBody WhDirectApplyInfo whDirectApplyInfo)
    {
        return toAjax(whDirectApplyInfoService.updateWhDirectApplyInfo(whDirectApplyInfo));
    }

    /**
     * 删除工地直转信息
     */
    @ApiOperation(value = "删除工地直转信息")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:info:remove")
    @SysLog(title = "工地直转信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除工地直转信息")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(whDirectApplyInfoService.deleteWhDirectApplyInfoByIds(ids));
    }
}
